# Funcão para utilizar o progama

Meu progama tem somente uma funcão!
Essa função tem a finalidade de receber um valor float ou int e devolver o valor informado com as casas de decimal, milhar, milhão... com seus pontos e virgula, No formato BRL.

# EXEMPLO 1:

formatar(200) # Retorno --> R$ 200,00

# EXEMPLO 2:
    
formatar(200.55) # Retorno --> R$ 200,55

# EXEMPLO 3:
    
formatar(120030) # Retorno --> R$ 120.030,00

Assim sucessivamente!